@@ -13,15 +13,10 @@ class QolsysTableIqRouterNetworkConfig(QolsysTable):
         self._uri = "content://com.qolsys.qolsysprovider.IQRouterNetworkConfigContentProvider/iqrouter_network_config_table"
         self._table = "iqrouter_network_config_table"
         self._abort_on_error = False
+        self._implemented = False
 
         self._columns = [
             "_id",
         ]
 
         self._create_table()
-
-    def insert(self, data: dict) -> None:
-        if data is not None:
-            LOGGER.error("Please Report")
-            LOGGER.error("Loading Table Format: %s", self.uri)
-            LOGGER.error(data)
